#------------------------------------------------------------
# Instrumental variables analysis (natural deaths) for:
# "Political Turnover and Chinese Development Cooperation"
# 03-29-2018
# Matthew DiLorenzo and Mengfan Cheng
#------------------------------------------------------------

library(tidyverse)
library(MASS)
library(sandwich)
library(lmtest)
library(stargazer)
library(plm)

source("~/Dropbox/r/basic-custom-functions.R")

setwd("~/Dropbox/working-papers/china-aid-turnover/data/")

dat <- read.csv("china-aid-turnover-data.csv",
                stringsAsFactors = FALSE)

## For table output
dat <- dat %>%
  rename(election = election_year)

dat <- dat %>%
  mutate(civil_conflicts = ifelse(civil_conflicts > 0, 1, 0))

test <- dat %>%
  group_by(statename) %>%
  summarise(n_change = mean(taiwan_recognition, na.rm = T))


#-------------------------------------------------------
# Add Archigos data
#-------------------------------------------------------


## Load Archigos data
archigos <- read.table("archigos-4.0-leader-year.txt",
                       header = T)

## Create a year variable
archigos$year <- sapply(as.character(archigos$startobs),
                        function(x) {
                          strsplit(x,
                                   "-", 
                                   fixed = TRUE)[[1]][1]}) %>% as.numeric()

## Change Yemen code
archigos <- mutate(archigos,
                   ccode = replace(ccode, idacr == "YEM", 679))


nat_death <- archigos %>%
  filter(year %in% 2000:2014) %>%
  filter(exit == "Natural Death") %>%
  group_by(leadid) %>%
  mutate(max_year = max(year)) %>%
  filter(year == max_year) %>%
  mutate(iso3c = countrycode(idacr, "cowc", "iso3c")) %>%
  ungroup() %>%
  dplyr::select(iso3c, year)

## Make vector of natural death ISO3-years
nat_deaths <- paste0(nat_death$iso3c, "-", nat_death$year)

## Make natural death variable
dat$natural_death <- ifelse(paste0(dat$iso3c, "-", dat$year) %in% nat_deaths,
                            1, 0)

#-------------------------------------------------------
# Regression table 1
#-------------------------------------------------------

## Make panel data frame
pdat <- pdata.frame(dat %>% arrange(iso3c, year),
                    index = c("iso3c", "year"))

first_stage <- plm(sols_change_dummy ~ natural_death + 
                     other_leader_trans +
                     regtrans_alt +
                     civil_conflicts +
                     ln_gdp +
                     n_disasters +
                     taiwan_recognition +
                     ln_china_total_finance_t1,
                   data = pdat,
                   method = "within",
                   effect = "twoways")

m1 <- plm(ln_china_total_finance ~ 
            sols_change_dummy +
            other_leader_trans +
            regtrans_alt +
            civil_conflicts +
            ln_gdp +
            n_disasters +
            taiwan_recognition +
            ln_china_total_finance_t1 | . - sols_change_dummy + natural_death,
          data = pdat,
          method = "within",
          effect = "twoways")

m2 <- update(m1,
             ln_china_oda ~ . - ln_china_total_finance_t1 + 
               ln_china_oda_t1)

m3 <- update(m1,
             ln_china_oof ~ . - ln_china_total_finance_t1 + 
               ln_china_oof_t1)

m4 <- update(m1,
             ln_china_grants ~ . - ln_china_total_finance_t1 + 
               ln_china_grants_t1)

m5 <- update(m1,
             ln_china_loans ~ . - ln_china_total_finance_t1 + 
               ln_china_loans_t1)

## Collect the five model objects in a list
china_models_amt <- list(m1, m2, m3, m4, m5)


## Get country-clustered estimated standard errors
china_clust_ses_amt <- lapply(china_models_amt,
                              function(x) 
                                sqrt(
                                  diag(
                                    vcovHC(x, 
                                           method = "arellano",
                                           type = "HC1")
                                  )
                                )
)


## Get number of countries for table output
china_countries_n <- sapply(china_models_amt,
                            function(x)
                              pdim(x)$nT$n)

## Prepare a table in LaTeX 
china_dv_labels <- c("All finance (log)",
                     "ODA-like (log)",
                     "OOF-like (log)",
                     "Grants (log)",
                     "Loans (log)")

covariates <- c("SOLS change",
                "Other leader change",
                "Regime change",
                "Civil conflict",
                #"Democracy",
                #"US ally",
                "GDP (log)",
                "Natural disasters",
                "Taiwan recognition")

setwd("~/Dropbox/working-papers/china-aid-turnover/tables/appendix/")
stargazer(china_models_amt,
          se = china_clust_ses_amt,
          dep.var.labels = china_dv_labels,
          covariate.labels = covariates,
          label = "china-iv-table-2",
          title = paste0("Domestic changes and Chinese finance, 2000-2014",
                         " (Instrumental variable: Natural death of leader)"),
          omit = c("year", "continent", "iso3c", "_t1"),
          p.auto = TRUE,
          t.auto = TRUE,
          digits = 3,
          column.sep.width = c("0pt"),
          notes.append = TRUE,
          notes.align = "l",
          notes.label = "",
          keep.stat = c("n", "f", "rsq"),
          add.lines = list(c("N. countries", china_countries_n)),
          font.size = "footnotesize",
          notes = c(
            "Two-tailed tests. Estimated standard errors clustered by recipient in parentheses.", 
            "Country- and year-fixed effects, lagged outcome (one-year) included in all models."),
          model.names = FALSE,
          model.numbers = TRUE,
          no.space = TRUE,
          out = "china-iv-table-2.tex",
          df = FALSE)


stargazer(first_stage,
          dep.var.labels = "SOLS Change (dummy)",
          covariate.labels = c("Natural death of leader", covariates[-1]),
          label = "china-iv-2-first-stage",
          title = paste0("Natural deaths and SOLS change, 2000-2014"),
          omit = c("year", "continent", "iso3c", "_t1"),
          p.auto = TRUE,
          t.auto = TRUE,
          digits = 3,
          column.sep.width = c("0pt"),
          notes.append = TRUE,
          notes.align = "l",
          notes.label = "",
          keep.stat = c("n", "f", "rsq"),
          add.lines = list(c("N. countries", china_countries_n)),
          font.size = "footnotesize",
          notes = c(
            "Two-tailed tests. Estimated standard errors in parentheses.", 
            "Country- and year-fixed effects."),
          model.names = FALSE,
          model.numbers = TRUE,
          no.space = TRUE,
          out = "china-iv-2-first-stage-table.tex",
          df = FALSE)

