#------------------------------------------------------------
# Linear probability models for appendix of:
# "Political Turnover and Chinese Development Cooperation"
# 07-21-2017
# Matthew DiLorenzo and Mengfan Cheng
#------------------------------------------------------------

library(tidyverse)
library(MASS)
library(sandwich)
library(lmtest)
library(stargazer)
library(plm)
source("~/Dropbox/r/basic-custom-functions.R")

setwd("~/Dropbox/working-papers/china-aid-turnover/data/")

dat <- read.csv("china-aid-turnover-data.csv",
                stringsAsFactors = FALSE)

## For table output
dat <- dat %>%
  rename(election = election_year)

dat <- dat %>%
  mutate(civil_conflicts = ifelse(civil_conflicts > 0, 1, 0))

## Make panel data frame
pdat <- pdata.frame(dat %>% arrange(iso3c, year),
                    index = c("iso3c", "year"))

#-------------------------------------------------------
# Regression table 1
#-------------------------------------------------------

m1 <- plm(I(n_chinese_projects > 0) ~ 
           sols_change_dummy +
           other_leader_trans +
           regtrans_alt +
           civil_conflicts +
           dem +
           ln_gdp +
           n_disasters +
           taiwan_recognition +
           ln_china_total_finance_t1,
         data = pdat,
         method = "within",
         effect = "twoways")

m2 <- update(m1,
             I(n_chinese_oda_projects > 0) ~ . - n_chinese_projects_t1 + 
               I(n_chinese_oda_projects_t1 > 0))

m3 <- update(m1,
             I(n_chinese_oof_projects > 0) ~ . - n_chinese_projects_t1 + 
               I(n_chinese_oof_projects_t1 > 0))

m4 <- update(m1,
             I(n_chinese_grants > 0) ~ . - n_chinese_projects_t1 + 
               I(n_chinese_grants_t1 > 0))

m5 <- update(m1,
             I(n_chinese_loans > 0) ~ . - n_chinese_projects_t1 +
               I(n_chinese_loans_t1 > 0))


## Collect the five model objects in a list
china_models_amt <- list(m1, m2, m3, m4, m5)

## Get country-clustered estimated standard errors
china_clust_ses_amt <- lapply(china_models_amt,
                              function(x) 
                                sqrt(
                                  diag(
                                    vcovHC(x, 
                                           method = "arellano",
                                           type = "HC1")
                                  )
                                )
)


## Get number of countries for table output
china_countries_n <- sapply(china_models_amt,
                            function(x)
                              pdim(x)$nT$n)


china_dv_labels <- c("All finance",
                     "ODA-like",
                     "OOF-like",
                     "Grants",
                     "Loans")

covariates <- c("SOLS change",
                "Other leader change",
                "Regime change",
                "Civil conflict",
                "Democracy",
                #"US ally",
                "GDP (log)",
                "Natural disasters",
                "Taiwan recognition")

setwd("~/Dropbox/working-papers/china-aid-turnover/tables/appendix/")
sink("china-lpm-table-1.tex")
stargazer(china_models_amt,
          se = china_clust_ses_amt,
          dep.var.labels = china_dv_labels,
          covariate.labels = covariates,
          label = "appx-lpm-models",
          title = "Domestic changes and Chinese aid, 2000-2014 (Dichotomous aid/no aid outcome)",
          omit = c("year", "continent", "iso3c", "_t1"),
          p.auto = TRUE,
          t.auto = TRUE,
          digits = 3,
          column.sep.width = c("0pt"),
          notes.append = TRUE,
          notes.align = "l",
          notes.label = "",
          keep.stat = c("n", "f", "rsq"),
          #single.row = TRUE,
          font.size = "scriptsize",
          notes = c("Two-tailed tests. Estimated standard errors clustered by recipient country in parentheses.", 
                    "OLS estimates. Country, year dummies, and lagged outcome (one-year lag) included in all models."),
          #float.env = "sidewaystable",
          model.names = FALSE,
          model.numbers = TRUE,
          no.space = TRUE,
          df = FALSE)
sink()

